==> haskell-utf8-string-1.0.2-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-utf8-string.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 utf8-string
version:              1.0.2
visibility:           public
id:                   utf8-string-1.0.2-FSV4F6pxd5y7PjtRkbEpDf
key:                  utf8-string-1.0.2-FSV4F6pxd5y7PjtRkbEpDf
license:              BSD-3-Clause
maintainer:           emertens@galois.com
author:               Eric Mertens
homepage:             https://github.com/glguy/utf8-string/
synopsis:             Support for reading and writing UTF8 Strings
description:
    A UTF8 layer for Strings. The utf8-string
    package provides operations for encoding UTF8
    strings to Word8 lists and back, and for reading and
    writing UTF8 without truncation.

category:             Codec
abi:                  581f40d1c64e588156b3773dd15f1b0b
exposed:              True
exposed-modules:
    Codec.Binary.UTF8.Generic Codec.Binary.UTF8.String
    Data.ByteString.Lazy.UTF8 Data.ByteString.UTF8 Data.String.UTF8

import-dirs:          /usr/lib/ghc-9.0.1/site-local/utf8-string-1.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/utf8-string-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/utf8-string-1.0.2
hs-libraries:         HSutf8-string-1.0.2-FSV4F6pxd5y7PjtRkbEpDf
depends:              base-4.15.0.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-utf8-string/html/utf8-string.haddock
haddock-html:         /usr/share/doc/haskell-utf8-string/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-utf8-string-1.0.2-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-utf8-string.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 utf8-string
version:              1.0.2
visibility:           public
id:                   utf8-string-1.0.2-5HCL2DEngO97ScKqywgmIk
key:                  utf8-string-1.0.2-5HCL2DEngO97ScKqywgmIk
license:              BSD-3-Clause
maintainer:           emertens@galois.com
author:               Eric Mertens
homepage:             https://github.com/glguy/utf8-string/
synopsis:             Support for reading and writing UTF8 Strings
description:
    A UTF8 layer for Strings. The utf8-string
    package provides operations for encoding UTF8
    strings to Word8 lists and back, and for reading and
    writing UTF8 without truncation.

category:             Codec
abi:                  9349484a1d7baed5490864d0889ee764
exposed:              True
exposed-modules:
    Codec.Binary.UTF8.Generic Codec.Binary.UTF8.String
    Data.ByteString.Lazy.UTF8 Data.ByteString.UTF8 Data.String.UTF8

import-dirs:          /usr/lib/ghc-9.0.1/site-local/utf8-string-1.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/utf8-string-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/utf8-string-1.0.2
hs-libraries:         HSutf8-string-1.0.2-5HCL2DEngO97ScKqywgmIk
depends:              base-4.15.0.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-utf8-string/html/utf8-string.haddock
haddock-html:         /usr/share/doc/haskell-utf8-string/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
